desc 'Prepares basic project structure and configuration.'
task :prepare_project do |t, args|
  require 'fileutils'
  require 'uu_os_connection-server/version'
  require 'uu/os/util/name_converter'

  puts "Creating basic project structure"
  # app
  app_dir = File.join(Dir.pwd, 'app')
  Dir.mkdir(app_dir) unless File.directory?(app_dir)
  # app/controllers
  controllers_dir = File.join(app_dir, 'controllers')
  Dir.mkdir(controllers_dir) unless File.directory?(controllers_dir)
  # app/helpers
  helpers_dir = File.join(app_dir, 'helpers')
  Dir.mkdir(helpers_dir) unless File.directory?(helpers_dir)
  
  # test
  test_dir = File.join(Dir.pwd, 'test')
  Dir.mkdir(test_dir) unless File.directory?(test_dir)
  # test/controllers
  controllers_dir = File.join(test_dir, 'controllers')
  Dir.mkdir(controllers_dir) unless File.directory?(controllers_dir)
  # test/helpers
  helpers_dir = File.join(test_dir, 'helpers')
  Dir.mkdir(helpers_dir) unless File.directory?(helpers_dir)

  puts "Creating basic configuration files"
  cfgru = File.join(Dir.pwd, 'config.ru')
  if !File.exists?(cfgru)
    out = File.open(cfgru, 'w+')
    out.write("require 'bundler'\n")
    out.write("Bundler.require\n\n")
    out.write("initialize_server\n")
    out.close
  end
  gemfile = File.join(Dir.pwd, 'Gemfile')
  if !File.exists?(gemfile)
    out = File.open(gemfile, 'w+')
    out.write("source 'http://gems.plus4u.net' do\n")
    out.write("  gem 'uu_os_connection-server', '~>#{UUOSConnectionServer::VERSION.split('.')[0..1].join('.')}'\n")
    out.write("end\n\n")
    out.write("source 'http://rubygems.org' do\n")
    out.write("  # Thirdparty dependencies...\n")
    out.write("end\n\n")
    out.close
  end
 
  splited_folder_name = File.basename(Dir.pwd).split('-')
  basename = splited_folder_name[0].downcase
  classifier = splited_folder_name[1].downcase unless splited_folder_name[1].nil?
  
  puts "Creating version file"
  version = File.join(app_dir, 'version.rb')
  if !File.exists?(version)
    out = File.open(version, 'w+')
    out.write("module #{UU::OS::Util::NameConverter.to_upper_camel_case(basename)}\n")
    out.write("  module #{UU::OS::Util::NameConverter.to_upper_camel_case(classifier)}\n  ") unless classifier.nil?
    out.write("  VERSION = '0.0.1'\n")
    out.write("  end\n") unless classifier.nil?
    out.write("end\n")
    out.close
  end

end
